<?php
if(!defined('TEMPLATEPATH')) {
	define( 'TEMPLATEPATH', get_bloginfo('stylesheet_directory'));
}

if (function_exists('register_sidebar')) {
	register_sidebar(array(
		'name'=> __('nihil bar', 'nihil'),
		'id' => 'nihil-bar',
		'before_widget' => '<li id="%1$s">',
		'after_widget' => '</li>',
		'before_title' => '<h2>',
		'after_title' => '</h2>',
	));
}

if ( ! function_exists( 'nihil_init' ) ) :
function nihil_init() {

	load_theme_textdomain ('nihil');

	define('MARIGINARI_THEME_IS_ACTIVE', true);
	define('MARIGINARI_MONTHLY_ARCHIVE_DATE_FORMAT', "F Y");
	define('MARIGINARI_PREFERS_WYSIWYG_COMMENTS', true);

	if ( function_exists('add_editor_style') ) {
		add_editor_style('editor-style.css.php');
	}

	if ( function_exists('add_theme_support') ) {
		// Add default posts and comments RSS feed links to head
		add_theme_support( 'automatic-feed-links' );
	}

	$GLOBALS['nihil'] = new Nihil();
}
endif;
if(version_compare(get_bloginfo('version'), '3.0') < 0) {
	nihil_init();
}
else {
	add_action( 'after_setup_theme', 'nihil_init' );
}

class Nihil {

	function __construct() {

		// Hook up theme and plugins' JavaScript.
		add_action( 'wp_print_scripts', array($this, 'script') );

		// Work around miscapitalization in translation.
		add_filter( 'get_comment_date', array( $this, $this->get_date_wrapper() )  );

		// Comment / ping separation based on http://sivel.net/2008/10/wp-27-comment-separation/
		add_filter( 'get_comments_number', array($this, 'comment_count'), 0 );
	}
	function script() {
		wp_enqueue_script('nihil-script', TEMPLATEPATH.'/javascript.php', array(), '9001');
	}
	function comment_count( $count ) {
	        global $id;

		if ( is_admin() ) {
		        return $count;
		}

	        $comments_by_type = &separate_comments(get_comments('status=approve&post_id=' . $id));
	        return count($comments_by_type['comment']);
	}



	public function echo_404_suggestions() {
		global $s;
		$suggestions = $this->get_404_suggestions();
		if ($suggestions === false) {
			echo "<p>".__("This address doesn't have a specific post attached to it, "
				."and no posts related to what you requested were found. This might be due to", 'nihil')."</p>";
		}
		else {
			echo "<p>";
			_e("This address doesn't have a specific post attached to it.", 'nihil');
			echo " " . $suggestions;
			echo "</p>";
			echo "<p>".__("If this wasn't what you were looking for, it might be due to", 'nihil')."</p>";
		}
		echo "<ul>
			<li>".__('a post or archive page having been removed', 'nihil')."</li>
			<li>".__('a broken link', 'nihil')."</li>
			<li>".__('a typing error.', 'nihil')."</li>
</ul>";
		echo "<p>".sprintf(__('Please try the search function below or '
			.'<a href="%1$s" title="Archive by date at the sidebar">the yearly archive in the sidebar</a>. '
			.'You can also go back in post history using the "Older Posts" link at the '
			.'<a href="%2$s">bottom of the front page</a>.', 'nihil'),
			'#collapsible-archive', get_bloginfo('url').(substr(get_bloginfo('url'),-1) == '/' ? '' : '/').'#chronology')."</p>";
		?><form method="get" id="bigsearchform" action="<?php bloginfo('url'); ?>">
		<div>
			<label for="s"><?php _e('Search for...', 'nihil'); ?></label>
			<input class="text" type="text" value="<?php
				if ( empty($s) ) {
					$s = trim(htmlentities(stripslashes(urldecode(get_query_var('name')))));
				}
				echo $s; ?>" name="s" id="s" />
			<input type="submit" class="submit" name="Submit" value="<?php _e('Go!', 'nihil'); ?>" />
		</div>
	</form><?php
	}

	// Mimicked this from http://svn.automattic.com/wordpress/trunk/wp-includes/canonical.php
	function get_404_suggestions() {
		global $wpdb;

		if ( !get_query_var('name') )
			return false;

		// Store for re-use later.
		$name = get_query_var('name');

		// if any of year, monthnum, or day are set, use them to refine the query
		if ( get_query_var('year') )
			$where_date = $wpdb->prepare(" AND YEAR(post_date) = %d", get_query_var('year'));
		if ( get_query_var('monthnum') )
			$where_date = $wpdb->prepare(" AND MONTH(post_date) = %d", get_query_var('monthnum'));
		if ( get_query_var('day') )
			$where_date = $wpdb->prepare(" AND DAYOFMONTH(post_date) = %d", get_query_var('day'));

		$where = $wpdb->prepare("post_name LIKE %s", $name . '%') .$where_date;
		$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");

		if ( !$post_id ) {
			$where = $wpdb->prepare("post_name LIKE %s", '%' . $name) .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_name LIKE %s", '%' . $name . '%') .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_title LIKE %s", $name . '%') .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_title LIKE %s", '%' . $name) .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}
		if ( !$post_id ) {
			$where = $wpdb->prepare("post_title LIKE %s", '%' . $name . '%') .$where_date;
			$post_id = $wpdb->get_var("SELECT ID FROM $wpdb->posts WHERE $where AND post_status = 'publish'");
		}

		if ( !$post_id ) {
			return false;
		}
		return '<span class="nihil-suggestions">'
				.sprintf(__('Did you mean: %s', 'nihil'),
					'<a href="'.get_permalink($post_id)
					.'" title="'.$this->get_the_title_attribute($post_id).'"><em><strong>'
					.get_the_title($post_id).'</strong></em></a>')
			.'</span>';
	}


	// WP's the_title_attribute() is crap.
	public function get_the_title_attribute($ID = 0) {
		$title = get_the_title($ID);

		if ( strlen($title) == 0 )
			return;

		return esc_attr(strip_tags($title));
	}

	public function get_monthly_archive_date_format() {
		return MARIGINARI_MONTHLY_ARCHIVE_DATE_FORMAT;
	}
	public function get_date_wrapper() {
		$options = get_option("nihil");
		return $options['date_wrapper'] ? 'date_ucfirst' : 'date_unchanged';
	}
	public function date_ucfirst($date) {
		return ucfirst(strtolower($date));
	}
	public function date_unchanged($date) {
		return $date;
	}




	// some abstract meta-functions for functionality-detection and on-the-fly en-/disabling.
	// these need to be updated with the plugins or if the plugin providing the functionality is changed.
	public function prefers_wysiwyg_comments() {
		return MARIGINARI_PREFERS_WYSIWYG_COMMENTS;
	}
	public function has_wysiwyg_comments() {
		return has_action('wp_head', 'mcecomment_init');
	}
	public function uses_wysiwyg_comments() {
		return ( !$this->has_comment_preview() ? 'true' : 'false');
		return ( $this->has_wysiwyg_comments() && ( $this->prefers_wysiwyg_comments() || !$this->has_comment_preview() ) );
	}
	public function disable_wysiwyg_comments() {
		return remove_action('wp_head', 'mcecomment_init');
	}
	public function has_comment_preview() {
		return has_action('comment_form', 'lcp_add_preview_div');
	}
	public function disable_comment_preview() {
		return remove_action('comment_form', 'lcp_add_preview_div');
	}
	public function uses_comment_preview() {
		return ( $this->has_comment_preview() && !$this->prefers_wysiwyg_comments() );
	}



	public function tags_page_tags_list() {
		$show_em_like_this = array(
		'smallest'  => 4, 
		'largest'   => 32,
		'unit'      => 'pt', 
		'number'    => 0,  
		'format'    => 'list',
		'separator' => '
	',
		'orderby'   => 'name', 
		'order'     => 'ASC',
//		'exclude'   => ,
//		'include'   => ,
		'link'      => 'view', 
		'taxonomy'  => 'post_tag', 
		'echo'      => true
		);

		wp_tag_cloud($show_em_like_this);
	}

	public function categories_page_categories_list() {
		$show_em_like_this = array(
//			'show_option_all'    => ,
			'orderby'            => 'name',
			'order'              => 'ASC',
			'show_last_update'   => 0,
			'style'              => 'list',
			'show_count'         => 1,
			'hide_empty'         => 1,
			'use_desc_for_title' => 1,
			'child_of'           => 0,
//			'feed'               => ,
//			'feed_type'          => ,
			'feed_image'         => get_bloginfo('template_url').'/images/rss-12.png',
//			'exclude'            => ,
//			'exclude_tree'       => ,
//			'include'            => ,
			'current_category'   => 0,
			'hierarchical'       => true,
			'title_li'           => '',
			'number'             => NULL,
			'echo'               => 1,
			'depth'              => 0
		);

		echo '<ul class="all-categories">';
		wp_list_categories($show_em_like_this);
		echo '</ul>';
	}

	// http://erikt.tumblr.com/post/278953342/get-a-wordpress-page-id-with-the-slug
	function get_ID_by_slug($slug) {
		$page = get_page_by_path($slug);
		if ($page) {
			return $page->ID;
		} else {
			return null;
		}
	}
	public function post($is_404 = false) {
		global $post;
		if ( $is_404 ) {
			$id = $this->get_ID_by_slug(__('404-not-found', 'nihil'));
			if (is_numeric($id)) {
				$post = get_post($id);
				setup_postdata($post);
			}
			else {
				// a quick and nasty fallback.
				?><div class="article not-found">
					<h2 class="post-title"><?php _e("Let's find that post!", 'nihil'); ?></h2>
					<div class="content"><?php $this->echo_404_suggestions(); ?></div>
				</div><!-- end post -->
<br />
<br />
<br />
<?php
				return;
			}
		}
		?>




			<div <?php post_class(  'article'. ( is_singular() ? ' single' : '' )  ); ?> id="post-<?php the_ID();?>">
<?php $this->post_header();
		if ( $is_404 ) {
			$this->echo_404_suggestions();
		}
		else {
			the_content();
			if (  is_page( (get_option('category_base') ? get_option('category_base') : 'category') )  ) {
				$this->categories_page_categories_list();
			}
			if (  is_page( (get_option('tag_base') ? get_option('tag_base') : 'tag') )  ) {
				$this->tags_page_tags_list();
			}
		}

		$this->post_footer();
?>
			</div><!-- end post -->
<?php
	}

	public function post_header() {
		$date_wrapper = $this->get_date_wrapper();
		?>
				<div class="header">
					<h1>
						<a href="<?php the_permalink() ?>#post-<?php the_ID(); ?>"
						  title="<?php printf(
							__('Permanent Link: %s', 'nihil'), 
							the_title_attribute('before=&after=&echo=0')
						  ); ?>"
					  	rel="bookmark"><?php the_title(); ?></a>
					</h1>
					<h3>
						<a href="<?php bloginfo('url'); ?>/?p=<?php the_ID(); ?>"
						  title="<?php printf( __('Permanent Link: Post no. %d', 'nihil'), get_the_ID() ); ?>"
						  rel="bookmark">#<?php the_ID();?></a>.
						<?php echo sprintf(
							__('%s at %s', 'nihil'),
							ucfirst(get_the_time(get_option('date_format'))),
							get_the_time(get_option('time_format'))
						);
						echo ' | ';
						if (get_the_author_meta('user_url') != '') {
							?><a href="<?php the_author_meta('user_url'); ?>" title="<?php
							_e("Visit the author's homepage", 'nihil'); ?>"><?php the_author(); ?></a><?php 
						}
						else {
							the_author();
						}
						edit_post_link(__('Edit'), '
						| ', '');
						?>

					</h3>
				</div><!-- end post header -->

				<div class="section content">
<?php
	}

	public function respond_link() {
		?><a href="<?php the_permalink() ?>#respond"
			title="<?php printf( __('Respond to %s', 'nihil'), $this->get_the_title_attribute() ); ?>"><?php
		_e('Respond', 'nihil'); ?></a><?php
	}
	public function post_footer() {
		?>
				</div><!-- end post content -->

				<div class="footer">
					<?php
		if( get_the_tag_list() ) {
?>

					<?php the_tags('<h3 class="taxonomy tags">
'.__('Tags: ', 'nihil'),',
','
					</h3>');
?><?php
		}
		else {
?>

					<h3 class="taxonomy none">&nbsp;</h3>
<?php
		}
?>

				</div><!-- end post footer -->
<?php
	}

	public function nav_between_posts() {
		ob_start();
		previous_post_link( __('&laquo; %link', 'nihil') );
		$ppp = ob_get_contents();
		ob_end_clean();
		ob_start();
		next_post_link( __('%link &raquo;', 'nihil') );
		$ppn = ob_get_contents();
		ob_end_clean();

		if ( !empty($ppp) || !empty($ppn) ) {
		?>

		<div class="nav between posts" align="center">
<?php
			if ( !empty($ppp) ) { ?>
			<span class="prev"><?php echo $ppp; ?></span>
<?php
			}
			if ( !empty($ppp) && !empty($ppn) ) { ?>
			|
<?php			}
			if ( !empty($ppn) ) { ?>
			<span class="next"><?php echo $ppn; ?></span>
<?php
			} ?>
		</div>

<?php
		}
	}
	public function nav_between_archive_pages() {
		global $wp_query;
		ob_start();
		previous_posts_link( __('Newer Posts', 'nihil') );
		$ppn = ob_get_contents();
		ob_end_clean();
		ob_start();
		next_posts_link( __('Older Posts', 'nihil') );
		$ppo = ob_get_contents();
		ob_end_clean();
		if ( !empty($ppn) || !empty($ppo) ) {
			$current = ($wp_query->max_num_pages > 1 ? '<span class="currently-browsing">'.$this->get_paged_pages().'</span>' : '');
			?>
			<div class="nav between archive-pages" align="center"><?php if ( !empty($ppn) ) {
				?> <span class="prev"><?php echo '&laquo;&nbsp;'.$ppn; ?></span><?php
			}
			echo $current;
			if ( !empty($ppo) ) {
				?> <span class="next"><?php echo $ppo.'&nbsp;&raquo;'; ?></span><?php
			}
			?>
			</div>

<?php
		}
	}


	public function get_currently_browsing() {
		global $wp_query;
		global $s;
		$currently = '';
		if ( is_home() ) {
			$currently .= sprintf(__('the latest posts', 'nihil') );
		}
		else if ( is_search() ) {
			$searched_for = trim( wp_specialchars($s,1) );
			$searched_for = ( empty($searched_for) ? __('nothing', 'nihil') : $searched_for );
			$currently .= sprintf(__('search results for %1$s', 'nihil'), '<em><strong>'.$searched_for.'</strong></em>');
		}
		else if ( is_category() ) {
			$currently .= sprintf(__('posts in category %1$s', 'nihil'), single_cat_title('', false) );
		}
		else if ( is_tag() ) {
			$currently .= sprintf(__('posts tagged %s', 'nihil'), single_tag_title('', false) );
		}
		else if ( is_author() ) {
			global $wp_query;
			$curauth = $wp_query->get_queried_object();
			if ( empty($curauth) ) {
				$nick = $_GET['author'];
			}
			$currently .= sprintf(__('posts written by %s', 'nihil'), $curauth->display_name  );
		}
		else {
			$currently .= __('the archives ', 'nihil');
			if ( is_day() ) {
				$currently .= sprintf( __('for %s', 'nihil'), get_the_time(get_option('date_format')) );
			}
			else if ( is_month() ) {
				$currently .= sprintf( __('for %s', 'nihil'), get_the_time($this->get_monthly_archive_date_format()) );
			}
			else if ( is_year() ) {
				$currently .= sprintf(__('for %s', 'nihil'), get_the_time(__('Y', 'nihil')) );
			}
		}
		return $currently;
	}

	public function get_currently_browsing_page() {
		global $wp_query;
		global $paged;
		$currently = $this->get_currently_browsing();
		if ( !empty($currently) && $wp_query->max_num_pages > 1) {
			if ($paged > 0) {
				$cp = $paged;
				$pat = '/\/'.$paged.'\/?$/';
				$last = preg_replace($pat,'/'.$wp_query->max_num_pages.'/', $_SERVER["REQUEST_URI"]);
			}
			else {
				$cp = 1;
				$last = $_SERVER["REQUEST_URI"] . 'page/'.$wp_query->max_num_pages.'/';
			}
			if ($paged == $wp_query->max_num_pages) {
				$currently .= sprintf( __(', page %1$d of %1$d', 'nihil'), $wp_query->max_num_pages);
			}
			else {
				$currently .= sprintf( __(', page %1$d of <a href="%2$s" title="Page %3$d of %3$d">%3$d</a>', 'nihil'), $cp, $last, $wp_query->max_num_pages);
			}
		}
		return '			'
			.'<h1 class="you-are browsing">'
			.sprintf( __('You are browsing %s.', 'nihil'), $currently )
			.'</h1>';
	}

	public function get_paged_pages() {
		global $wp_query;
		global $paged;
		$paged_pages = '';
		if ($wp_query->max_num_pages > 1) {
			$page_base = 'page';
			if ($paged > 1) {
				$cp = $paged;
				$pat = '@'.$paged.'/$@';
				$paged_uri_base = preg_replace($pat, '', $_SERVER["REQUEST_URI"]);
				$unpat = '@/'.$page_base.'/'.$paged.'/$@';
				$unpaged_uri_base = preg_replace($unpat, '/', $_SERVER["REQUEST_URI"]);
			}
			else {
				$cp = 1;
				$unpaged_uri_base = $_SERVER["REQUEST_URI"];
				$paged_uri_base = $unpaged_uri_base . $page_base . '/';
			}

			$pages = array();
			$paging_limit = 5;	// keep it odd!
			$prefix = '';
			$trailer = '';
			if ($wp_query->max_num_pages > $paging_limit) {
				if ( $cp-($paging_limit / 2) < 1 ) {
					$start_from = 1;
				}
				else {
					if ($wp_query->max_num_pages - $cp-floor($paging_limit / 2) < $paging_limit) {
						$start_from = $wp_query->max_num_pages - $paging_limit +1;
					}
					else {
						$start_from = $cp-floor($paging_limit / 2);
					}

					if ($start_from > 1) {
						$prefix = '<a href="'.$unpaged_uri_base.'" title="'
							.sprintf( __('Page 1 of %1$d', 'nihil'), $wp_query->max_num_pages ).'">&laquo;</a>';
					}
				}
				if ( $cp+($paging_limit / 2) > $wp_query->max_num_pages ) {
					$go_until = $wp_query->max_num_pages;
				}
				else {
					if ( $cp+($paging_limit / 2) < $paging_limit ) {
						$go_until = $paging_limit;
					}
					else {
						$go_until = floor( $cp+($paging_limit / 2) );
					}

					if ($go_until < $wp_query->max_num_pages) {
						$trailer = '<a href="'.$paged_uri_base.$wp_query->max_num_pages.'/" title="'
							.sprintf( __('Page %1$d of %1$d', 'nihil'), $wp_query->max_num_pages ).'">&raquo;</a>';
					}
				}
			}
			else {
				$start_from = 1;
				$go_until = $wp_query->max_num_pages;
			}

			if ($start_from == 1) {
				$pages[1] = '<a href="'.$unpaged_uri_base.'" title="'
						.sprintf( __('Page 1 of %1$d', 'nihil'), $wp_query->max_num_pages ).'">1</a>';
				$start_from = 2;
			}
			for ($i = $start_from; $i <= $go_until; $i++) {
				$pages[$i] = '<a href="'.$paged_uri_base.$i.'/" title="'
					.sprintf( __('Page %1$d of %2$d', 'nihil'), $i, $wp_query->max_num_pages ).'">'.$i.'</a>';
			}
			$pages[$cp] = '<span title="'.sprintf( __('Page %1$d of %2$d', 'nihil'), $cp, $wp_query->max_num_pages )
					.'" class="current-paged-page">'.$cp.'</span>';
			$paged_pages = $prefix .' '. implode(' ', $pages) .' '. $trailer;
		}
		return $paged_pages;
	}

	public function list_comments($comment, $args, $depth) {

		$GLOBALS['comment'] = $comment;
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">

		<div class="header">
			<h2 class="meta"><small>
				<a href="<?php echo htmlspecialchars(get_comment_link($comment->comment_ID ) ) ?>"
				  title="<?php _e('Permanent link to this comment', 'nihil'); ?>"><?php printf('#%d', get_comment_ID());?></a>.
				<?php printf(__('%1$s at %2$s', 'nihil'), get_comment_date(), get_comment_time()); ?>
				<?php edit_comment_link(__('Edit')); ?>
			</small></h2>

			<span class="comment-author vcard"><?php echo get_avatar($comment,$size='32'); ?>
			<?php printf('<cite class="comment-citation">%s</cite>', get_comment_author_link()) ?></span>
		</div>

		<div class="section content"><?php comment_text() ?></div>

		<div class="footer">
			<?php if ($comment->comment_approved == '0') : ?>
			<p class="is-in-moderation"><small><strong><?php _e('This comment is in moderation.', 'nihil'); ?></strong></small></p>
			<?php endif; ?>
		</div>
<br />
<br />
<br />
		<?php
	}

	public function list_pings($comment, $args, $depth) {
		$GLOBALS['comment'] = $comment;
		?>
		<li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>"><a href="<?php
			echo htmlspecialchars(get_comment_link($comment->comment_ID ) ) ?>"
			title="<?php _e('Permanent link to this pingback', 'nihil'); ?>"><?php
			printf(__('%1$s at %2$s', 'nihil'), get_comment_date('j. F\t\a Y'), get_comment_time()) ?></a>
			| <?php printf('<cite class="comment-citation">%s</cite>', get_comment_author_link()) ?>

		<?php if ($comment->comment_approved == '0') {
			echo '<p class="moderated"><small><strong>'.__('This pingback is in moderation.', 'nihil').'</strong></small></p>';
		}
	}

	public function get_tabs() {

		$search = (is_search() ? ' is-current' : '');
		$search_form = "<div><form id=\"searchform\" method=\"get\" action=\"" . get_bloginfo('home') . "/\">
			<input type=\"text\" name=\"s\" id=\"s\" />
			<input type=\"submit\" value=\"".__('Search', 'nihil')."\" />
			</form></div>";

		$tabs = '<ul class="tabs">

		<li class="search'.$search.'">'.$search_form.'</li>
	</ul>';
		return $tabs;
	}



	/* from wp-includes/comment-template.php
	 */
	public function comments_template( $file = '/comments.php', $separate_comments = false ) {
		global $wp_query, $withcomments, $post, $wpdb, $id, $comment, $user_login, $user_ID, $user_identity, $overridden_cpage;

		if ( empty($file) )
			$file = '/comments.php';

		$req = get_option('require_name_email');

		/**
		 * Comment author information fetched from the comment cookies.
		 *
		 * @uses wp_get_current_commenter()
		 */
		$commenter = wp_get_current_commenter();

		/**
		 * The name of the current comment author escaped for use in attributes.
		 */
		$comment_author = $commenter['comment_author']; // Escaped by sanitize_comment_cookies()

		/**
		 * The email address of the current comment author escaped for use in attributes.
		 */
		$comment_author_email = $commenter['comment_author_email'];  // Escaped by sanitize_comment_cookies()

		/**
		 * The url of the current comment author escaped for use in attributes.
		 */
		$comment_author_url = esc_url($commenter['comment_author_url']);

		/** @todo Use API instead of SELECTs. */
		if ( $user_ID) {
			$comments = $wpdb->get_results($wpdb->prepare("SELECT * FROM $wpdb->comments WHERE comment_post_ID = %d AND (comment_approved = '1' OR ( user_id = %d AND comment_approved = '0' ) )  ORDER BY comment_date_gmt", $post->ID, $user_ID));
		} else if ( empty($comment_author) ) {
			$comments = get_comments( array('post_id' => $post->ID, 'status' => 'approve', 'order' => 'ASC') );
		} else {
			$comments = $wpdb->get_results($wpdb->prepare("SELECT * FROM $wpdb->comments WHERE comment_post_ID = %d AND ( comment_approved = '1' OR ( comment_author = %s AND comment_author_email = %s AND comment_approved = '0' ) ) ORDER BY comment_date_gmt", $post->ID, wp_specialchars_decode($comment_author,ENT_QUOTES), $comment_author_email));
		}

		// keep $comments for legacy's sake
		$wp_query->comments = apply_filters( 'comments_array', $comments, $post->ID );
		$comments = &$wp_query->comments;
		$wp_query->comment_count = count($wp_query->comments);
		update_comment_cache($wp_query->comments);

		if ( $separate_comments ) {
			$wp_query->comments_by_type = &separate_comments($comments);
			$comments_by_type = &$wp_query->comments_by_type;
		}

		$overridden_cpage = FALSE;
		if ( '' == get_query_var('cpage') && get_option('page_comments') ) {
			set_query_var( 'cpage', 'newest' == get_option('default_comments_page') ? get_comment_pages_count() : 1 );
			$overridden_cpage = TRUE;
		}

		if ( !defined('COMMENTS_TEMPLATE') || !COMMENTS_TEMPLATE)
			define('COMMENTS_TEMPLATE', true);

		$include = apply_filters('comments_template', STYLESHEETPATH . $file );
		if ( file_exists( $include ) )
			require( $include );
		elseif ( file_exists( TEMPLATEPATH . $file ) )
			require( TEMPLATEPATH .  $file );
		else
			require( get_theme_root() . '/'.WP_FALLBACK_THEME.'/comments.php');
	}

}
?>
